# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.9.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkflowTemplateDefinition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'task_id': 'str',
        'data': 'object',
        'opts': 'object',
        'children': 'list[WorkflowTemplateDefinition]'
    }

    attribute_map = {
        'task_id': 'taskId',
        'data': 'data',
        'opts': 'opts',
        'children': 'children'
    }

    def __init__(self, task_id=None, data=None, opts=None, children=None):  # noqa: E501
        """WorkflowTemplateDefinition - a model defined in Swagger"""  # noqa: E501
        self._task_id = None
        self._data = None
        self._opts = None
        self._children = None
        self.discriminator = None
        self.task_id = task_id
        if data is not None:
            self.data = data
        if opts is not None:
            self.opts = opts
        if children is not None:
            self.children = children

    @property
    def task_id(self):
        """Gets the task_id of this WorkflowTemplateDefinition.  # noqa: E501


        :return: The task_id of this WorkflowTemplateDefinition.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this WorkflowTemplateDefinition.


        :param task_id: The task_id of this WorkflowTemplateDefinition.  # noqa: E501
        :type: str
        """
        if task_id is None:
            raise ValueError("Invalid value for `task_id`, must not be `None`")  # noqa: E501

        self._task_id = task_id

    @property
    def data(self):
        """Gets the data of this WorkflowTemplateDefinition.  # noqa: E501


        :return: The data of this WorkflowTemplateDefinition.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this WorkflowTemplateDefinition.


        :param data: The data of this WorkflowTemplateDefinition.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def opts(self):
        """Gets the opts of this WorkflowTemplateDefinition.  # noqa: E501


        :return: The opts of this WorkflowTemplateDefinition.  # noqa: E501
        :rtype: object
        """
        return self._opts

    @opts.setter
    def opts(self, opts):
        """Sets the opts of this WorkflowTemplateDefinition.


        :param opts: The opts of this WorkflowTemplateDefinition.  # noqa: E501
        :type: object
        """

        self._opts = opts

    @property
    def children(self):
        """Gets the children of this WorkflowTemplateDefinition.  # noqa: E501


        :return: The children of this WorkflowTemplateDefinition.  # noqa: E501
        :rtype: list[WorkflowTemplateDefinition]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this WorkflowTemplateDefinition.


        :param children: The children of this WorkflowTemplateDefinition.  # noqa: E501
        :type: list[WorkflowTemplateDefinition]
        """

        self._children = children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowTemplateDefinition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowTemplateDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
